using System;
using NUnit.Framework;
using Stattauto.Domain.Reservierungen;

namespace Stattauto.Domain.Mitgliedschaften
{
	[TestFixture]
	public class MitgliedReservierungsberechtigtTest
	{
		private DateTime eintrittsDatum;
		private Mitglied mitglied;
		

		public MitgliedReservierungsberechtigtTest()
		{	
		}

		[SetUp]
		private void Init()
		{	
			eintrittsDatum = DateTime.Now;
			mitglied = new Mitglied(4711, "Hans", "Mustermann",eintrittsDatum);	
		}

		#region ohne Austritt
		[Test]
		public void OhneAustrittOk1()
		{
			DateTime reservierungsEnde = DateTime.Now.AddHours(5);
			Zeitraum reservierung = new Zeitraum(eintrittsDatum, reservierungsEnde);
			mitglied.Reservierungsberechtigt(reservierung);
		}

		[Test]
		public void OhneAustrittOk2()
		{
			Zeitraum reservierung = new Zeitraum(DateTime.Now.AddHours(5), DateTime.Now.AddHours(15));
			mitglied.Reservierungsberechtigt(reservierung);
		}

		[Test]
		public void OhneAustrittOk3()
		{
			Zeitraum reservierung = new Zeitraum(DateTime.Now.AddDays(1), DateTime.Now.AddDays(1).AddHours(5));
			mitglied.Reservierungsberechtigt(reservierung);
		}

		[Test]
		public void OhneAustrittNichtOk()
		{
			try
			{
				Zeitraum reservierung = new Zeitraum(DateTime.Now.AddDays(-1), DateTime.Now.AddDays(1).AddHours(5));
				mitglied.Reservierungsberechtigt(reservierung);
				Assertion.Fail(" ");
			}
			catch (ArgumentException exc)
			{

			}
		}
		#endregion

		#region mit Austritt			
		[Test]
		public void MitAustrittOk1()
		{
			Zeitraum reservierung = new Zeitraum(DateTime.Now.AddDays(4), DateTime.Now.AddDays(4).AddHours(1));
			mitglied.Austritt(DateTime.Now.AddDays(5));
			mitglied.Reservierungsberechtigt(reservierung);
		}
		
		[Test]
		public void MitAustrittOk2()
		{
			Zeitraum reservierung = new Zeitraum( DateTime.Now.AddDays(3), DateTime.Now.AddDays(4));
			mitglied.Austritt(DateTime.Now.AddDays(4));
			mitglied.Reservierungsberechtigt(reservierung);
		}

		[Test]
		public void MitAustrittNichtOk()
		{
			try
			{
				Zeitraum reservierung = new Zeitraum(DateTime.Now.AddDays(4), DateTime.Now.AddDays(4).AddHours(1));
				mitglied.Austritt(DateTime.Now.AddDays(3));
				mitglied.Reservierungsberechtigt(reservierung);
				Assertion.Fail("Test Nicht Ok Mit Austritt fehlgeschlagen");
			}
			catch (ArgumentException exp)
			{
			}
		}

		#endregion	 
	}
}
